@@ -19,18 +19,22 @@ def transliterate(text):
     trans = []
     parts = split_by_unicode_blocks(text)
     for part in parts:
-        for i in range(len(part[0])):
+        i = 0
+        while i < len(part[0]):
             c = part[0][i]
             t = None
             if i+1 < len(part[0]):
                 p = part[0][i:i+2]
                 t = transmap.get(p, None)
+                if t:
+                    i += 1
             if not t:
                 t = transmap.get(c, (c, None))
             if len(part[0]) > 1 and t[1]:
                 trans.append(t[1])
             else:
                 trans.append(t[0])
+            i += 1
     return u''.join(trans)
 
 if __name__ == '__main__':
